package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.38.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.38.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,``P`!````Y!4``#0```!,L0```````#0`(``,
M`"@`&0`8``8````T````-````#0```"``0``@`$```0````$`````P```+0!
M``"T`0``M`$``!<````7````!`````$````!````````````````````L`\`
M`+`/```$`````!````$`````$````!`````0``"/,P``CS,```4`````$```
M`0````!0````4````%```!Q.```<3@``!``````0```!````Y*T``.2M``#D
MK0``,`(``%P"```&`````!````(```#LK0``[*T``.RM``#P````\`````8`
M```$````!````,P!``#,`0``S`$``$P```!,````!`````0```!3Y71D\`$`
M`/`!``#P`0``*````"@````$````!````%#E=&1PD```<)```'"0```4`0``
M%`$```0````$````4>5T9```````````````````````````!@```!````!2
MY71DY*T``.2M``#DK0``'`(``!P"```$`````0```"]L:6(O;&0M;75S;"UI
M,S@V+G-O+C$```0````4`````P```$=.50`]FV>1-P$F>NO3P\8G!3$<:2K8
MU@0````8````!0```$=.50`!``'`!`````D````"``'`!`````$````1````
M1P````@````(`````!`0`"5`!(`H`!`$H(8`A("!``(+(`0).(`208H$"`@`
M````1P```$L```!/````4````%<```!8````60````````!;````7```````
M``!=````7@```&```````````````&I_FGSJT^\.SMY'+6_%WQ\NQ9NVN(WQ
M#M1DU'PA_^0.V7%8'/JA;&#"Y3\LL@&+;T+ZUX?B1\8!F$_#F[OCDGQ5PSS2
M9Z_,9H@'<--#1=7L,V+;[16,)<Q_J9R;X*<""FL:GE"CX/M)````````````
M``````````$``````````````!(````)```````````````1````T0$`````
M````````$0```%H!`````````````!(````0```````````````2````J@$`
M````````````$@```!@``````````````!(````?```````````````2````
MW@$`````````````$@```+8!`````````````!(```#H`@`````````````A
M````*```````````````$@```"X``````````````!(````U````````````
M```2````IP(`````````````$@```+T"`````````````!(```#Y`0``````
M```````2````/```````````````$@```'\"`````````````!(```!#````
M```````````2````2P``````````````$@```*`"`````````````!(```!3
M```````````````2````:`(`````````````$@```%L``````````````!(`
M``!D```````````````@````M@(`````````````$@```(``````````````
M`!(```"%```````````````2````=P$`````````````%@```(8"````````
M`````!(````F`@`````````````2````C@``````````````$@```)4`````
M`````````"`````8`@`````````````2````.P,`````````````$@```)$"
M`````````````!$```#G`@`````````````1````2@(`````````````$@``
M`-0"`````````````!(```#I`@`````````````1````LP``````````````
M$@```&@!`````````````!(```"\```````````````B````RP``````````
M````$@```(8``````````````!(````V`@`````````````2````T```````
M````````(````',"`````````````!(```#J```````````````2````FP$`
M````````````$@```.\``````````````"`````+`0`````````````2````
M6`(`````````````$@```!$!`````````````!(```"*`0`````````````2
M````'P$`````````````$@```#`!`````````````!(```#T`0``````````
M```2````!0(`````````````$@```#8!`````````````!(````_`@``````
M```````2````KP(`````````````$@```,P"`````````````!(```!%`0``
M```````````2````[P$`````````````$@```$P!`````````````!(```#Q
M`@`````````````2````Y@(`````````````(0```%,!`````````````!(`
M``#A`@``L!,``#0"```2``P`RP$``(A#```!````$@`-`'T#```@*0``\`8`
M`!(`#``Q!```0#(``,4````2``P`6@,``(`>```%````$@`,`.\#````$```
M`0```!(`"0"@`P``$#```"4"```2``P`%00``)`>```U`@``$@`,`-@#```4
ML````````!``%@!K`P``8"@``+P````2``P`B@,``"`=```V````$@`,`)(#
M````)@``80```!(`#`"V`P``8#\```8"```2``P`RP,``-`@```R````$@`,
M`.0#``!P)@``-````!(`#``L!```0+`````````0`!8`(`,``/\5```W````
M$@`,`/4#```0(0``Z0```!(`#`#!`P``$+````0````1`!4`#@0``!2P````
M````$``5`-T#``#D%0```````!``#`#L`P``$#\``$$````2``P`*0,``#`H
M```K````$@`,`$0#``!@'0``&0$``!(`#``B!```<$$``/\!```2``P``00`
M```B``#\`P``$@`,``!O<&5N9&ER`'-T9&5R<@!R96%L;&]C`&%C8V5S<P!S
M;G!R:6YT9@!L<V5E:P!G971P:60`<W1R8VUP`'5N;&EN:P!M96UM;W9E`'-T
M<FYC;7``<W1R<F-H<@!C;&]S961I<@!?251-7V1E<F5G:7-T97)434-L;VYE
M5&%B;&4`;W!E;@!V9G!R:6YT9@!S=')C:'(`7U]D97)E9VES=&5R7V9R86UE
M7VEN9F]?8F%S97,`<F5A9&QI;FL`7U]C>&%?9FEN86QI>F4`97AI=`!?251-
M7W)E9VES=&5R5$U#;&]N951A8FQE`')E860`7U]R96=I<W1E<E]F<F%M95]I
M;F9O7V)A<V5S`')M9&ER`%]?<W1A=%]T:6UE-C0`7U]E<G)N;U]L;V-A=&EO
M;@!M:V1I<@!?7VQS=&%T7W1I;64V-`!M96UC<'D`<W1R;&5N`&=E='5I9`!0
M97)L7W-Y<U]T97)M`%!E<FQ?<WES7VEN:70S`%!,7V-U<G)E;G1?8V]N=&5X
M=`!097)L7V%T9F]R:U]L;V-K`'!E<FQ?8V]N<W1R=6-T`%!E<FQ?9V5T7W-V
M`%!E<FQ?8W)O86M?;F]C;VYT97AT`%]F:6YI`%!,7V1O7W5N9'5M<`!097)L
M7VYE=UA37V9L86=S`'!E<FQ?9G)E90!097)L7VUG7W-E=`!097)L7V%T9F]R
M:U]U;FQO8VL`4&5R;%]S=E]S971P=@!097)L7V=V7V9E=&-H<'8`<&5R;%]R
M=6X`4&5R;%]N97=84P!P97)L7V1E<W1R=6-T`&)O;W1?1'EN84QO861E<@!P
M97)L7W!A<G-E`%!E<FQ?<V%F97-Y<VUA;&QO8P!P97)L7V%L;&]C`%!,7VUE
M;6]R>5]W<F%P`'-T<F-P>0!R96%D9&ER`'-T<G1O:P!S=')D=7``<'1H<F5A
M9%]A=&9O<FL`<W!R:6YT9@!?7VQI8F-?<W1A<G1?;6%I;@!?7U]E;G9I<F]N
M`%]?<W1A8VM?8VAK7V9A:6P`;&EB<&5R;"YS;P!L:6)C+FUU<VPM>#@V+G-O
M+C$`7W-T87)T7V,`9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U:60`<&%R7V-U
M<G)E;G1?97AE8U]P<F]C`'!A<E]C=7)R96YT7V5X96,`<&%R7W-E='5P7VQI
M8G!A=&@`<&%R7VUK=&UP9&ER`'AS7VEN:70`<&%R7V5N=E]C;&5A;@!84U])
M;G1E<FYA;'-?4$%27T)/3U0`<VAA7W5P9&%T90!M>5]P87)?<&P`<&%R7V)A
M<V5N86UE`%]?8G-S7W-T87)T`'!A<E]D:64`<VAA7VEN:70`<&%R7V1I<FYA
M;64`<&%R7VEN:71?96YV`%]E9&%T80!P87)?9FEN9'!R;V<`<VAA7V9I;F%L
M`%]E;F0`<&%R7V-L96%N=7``+W5S<B]L:6(O<&5R;#4O8V]R95]P97)L+T-/
M4D4``.2M```(````Z*T```@```#`KP``"````,RO```(````U*\```@`````
ML```"````!"P```(````Q*\```8"``#(KP``!@,``-"O```&&@``V*\```X>
M``#<KP``!B(``."O```&)0``Y*\```8I``#HKP``!BP``.RO```&,```\*\`
M``8T``#TKP``!C8``/BO```&.```_*\```8\``#HK@``!P$``.RN```'!```
M\*X```<%``#TK@``!P8``/BN```'!P``_*X```<(````KP``!PD```2O```'
M"@``"*\```<,```,KP``!PT``!"O```'#@``%*\```</```8KP``!Q```!RO
M```'$0``(*\```<2```DKP``!Q,``"BO```'%```+*\```<5```PKP``!Q8`
M`#2O```'%P``.*\```<8```\KP``!QD``$"O```'&P``1*\```<<``!(KP``
M!QT``$RO```''P``4*\```<@``!4KP``!R$``%BO```'(P``7*\```<D``!@
MKP``!R<``&2O```'*```:*\```<J``!LKP``!RL``'"O```'+0``=*\```<N
M``!XKP``!R\``'RO```',0``@*\```<R``"$KP``!S,``(BO```'-0``C*\`
M``<W``"0KP``!SD``)2O```'.@``F*\```<[``"<KP``!ST``*"O```'/@``
MI*\```<_``"HKP``!T```*RO```'00``L*\```="``"TKP``!T,``+BO```'
M1```O*\```=&````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`(/L#(/$#,,```````````#_LP0```#_HP@`````````_Z,,````:`````#I
MX/____^C$````&@(````Z=#_____HQ0```!H$````.G`_____Z,8````:!@`
M``#IL/____^C'````&@@````Z:#_____HR````!H*````.F0_____Z,D````
M:#````#I@/____^C*````&@X````Z7#_____HRP```!H0````.E@_____Z,P
M````:$@```#I4/____^C-````&A0````Z4#_____HS@```!H6````.DP____
M_Z,\````:&````#I(/____^C0````&AH````Z1#_____HT0```!H<````.D`
M_____Z-(````:'@```#I\/[___^C3````&B`````Z>#^____HU````!HB```
M`.G0_O___Z-4````:)````#IP/[___^C6````&B8````Z;#^____HUP```!H
MH````.F@_O___Z-@````:*@```#ID/[___^C9````&BP````Z8#^____HV@`
M``!HN````.EP_O___Z-L````:,````#I8/[___^C<````&C(````Z5#^____
MHW0```!HT````.E`_O___Z-X````:-@```#I,/[___^C?````&C@````Z2#^
M____HX````!HZ````.D0_O___Z.$````:/````#I`/[___^CB````&CX````
MZ?#]____HXP```!H``$``.G@_?___Z.0````:`@!``#IT/W___^CE````&@0
M`0``Z<#]____HY@```!H&`$``.FP_?___Z.<````:"`!``#IH/W___^CH```
M`&@H`0``Z9#]____HZ0```!H,`$``.F`_?___Z.H````:#@!``#I</W___^C
MK````&A``0``Z6#]____H[````!H2`$``.E0_?___Z.T````:%`!``#I0/W_
M__^CN````&A8`0``Z3#]____H[P```!H8`$``.D@_?___Z/`````:&@!``#I
M$/W___^CQ````&AP`0``Z0#]____H\@```!H>`$``.GP_/___Z/,````:(`!
M``#IX/S___^CT````&B(`0``Z=#\____H]0```!HD`$``.G`_/___Z/8````
M:)@!``#IL/S___^CW````&B@`0``Z:#\____H^````!HJ`$``.F0_/___Z,`
M`0``9I#_HPP!``!FD/^C%`$``&:0```````````/"P\+#PMFD&:09I!FD&:0
MC4PD!(/D\/]Q_%6)Y5>)SU93Z&\"``"!PQ6;``!1@^PLBT$$B474BT$(B470
M9:$4````B47D,<"-1=!0C4744%'H.O[__XN#(`$``(/$#%!0_[,<`0``Z-3\
M__^+@^P```"#Q!"`.``/A!<!``"+@_P```!EBP"`B-("```#BP>-<`.#P`2)
M=<P]____/P^'<P$``(/L#,'@`E#H(/[__XMUU(L_@\00B<&)@UP!``"+!HD!
MC8/\HO__B4$$BX,T`0``B4$(C8/_HO__B4$,@_\!#XY#`0``B4W(C48$C5$0
MC32^C70F`(L(@\`$@\($B4K\.<9U\8M-R(/'`X/L#(V#Y&W__\<$N0````!J
M`%'_=<Q0_[-@`0``Z)'\__^#Q""%P`^$CP```(/L#/^S8`$``(U]X.@5_?__
MB?J)QHV#N*'__^B6`@``@\00A<!T?H/L#/^S8`$``.@Q_O__Z!S[__^#Q!"+
M1>1E*P44````#X6X````C67PB?!96UY?78UA_,/H=OS__XF#8`$``(7`#X2-
M````@^P,4.@__?__BX/\````@\0098L0QH*F!0```.F[_O__@^P,_[-@`0``
MZ.G\__^#Q!#I6____XN#6`$``(7`=!&#[`Q0Z*X<``"#Q!#I9____XGZC8-M
MH?__Z.D!``")@U@!``"%P`^$3/___^O24%"-@VBA____LP0!``!0Z,7Z__^_
M!````.G8_O__@^P,:@'H8?S__^B++0``,>V)X(/D\%!0Z`````"!!"3ZEP``
M4.@`````4^@Q````@</7F```@^P0BT0D&&H`C5`$_[/P````_[/X````4O\P
M_[/D````Z-_[__^#Q"A;PXL<),-FD&:09I#H10$``('"EY@``(V*.`$``(V"
M.`$``#G(=!V+@O0```"%P'0358GE@^P44?_0@\00R<,NC70F`,.-M"8`````
MZ`4!``"!PE>8``!5B>53C8HX`0``C8(X`0``@^P$*<B)P\'H'\'[`@'8T?AT
M%(N2$`$``(72=`J#[`A04?_2@\00BUW\R<,NC;0F`````)!5B>53Z%W___^!
MPP.8``"#[`2`NS@!````=4.+DPP!``"%TG01@^P,_[,D`0``Z(7\__^#Q!#H
M-?___XN#``$``(7`=!*#[`R-@_CB__]0Z%S\__^#Q!#&@S@!```!BUW\R<,N
MC;0F`````"Z-="8`5>@`````6H'"EI<``(GE4^CA_O__@<.'EP``@^P$BX,4
M`0``A<!T&8V#/`$``%)J`%"-@_CB__]0Z!+\__^#Q!"+7?S)Z?;^__^+%"3#
M9I!55U93Z)W^__^!PT.7``"#[!R)5"0(A<`/A+(```")P8N#"`$``(L0A=(/
MA*`````/M@&$P'0$/#UU53'MBS*%]G0\B50D#(GPB=:)3"0$B<>-M"8`````
M@^P$5?]T)`Q7Z#KY__^#Q!"%P'4&@#PO/70UBWX$@\8$A?]UVXG^@\0<B?!;
M7E]=PXVT)@````")S0^V10&#Q0&$P'0$/#UU\2G-ZYB-=@"+5"0,B?B)]XG&
MBT0D""G7C70N`<'_`HDX@\0<B?!;7E]=PRZ-="8`@\0<,?9;B?!>7UW#C70F
M`%:)QE/HO?W__X'#8Y8``('LK````&6A%````(F$)*0````QP(U$)!105NA1
M^O__@\00A<!U.HM4)!R!X@#P``"!^@!```!T"('Z`*```'4B@^P(:@)6Z)7W
M__^#Q!"%P`^4P`^VP.L*+HVT)@`````QP(N4))P```!E*Q44````=0F!Q*0`
M``!;7L/H;RH``%575HG&4^@K_?__@</1E0``@>R\````9:$4````B80DK```
M`#'`A?9T!8`^`'4ABX0DK````&4K!10````/A2X!``"!Q+P```!;7E]=PV:0
M@^P,5NC']O__@\00B<>%P'3-@^P,5^AE]___@\00A<`/A+(```"`>!,NC5`3
M=0F`>@$`=-V-=@"`>!,N#X2V````B50D#(/L#%;HL?G__XM4)!R)Q8D4)(E4
M)!SHG_G__XU$!0*)!"3H4_?__XM4)!R)Q8V#)*'__U)64%7H3OG__X/$&(U$
M)"105>C0^/__@\00@_C_=!"+1"0L)0#P```]`$```'1P@^P,5>C_]O__@\00
M@^P,5>C3^/__@\00@^P,5^BW]O__@\00A<`/A5+___^-="8`@^P,5^@_]___
MB30DZ&?X__^#Q!#I[O[__XVT)@````"`>@$N#X5`____@'H"``^$!O___^DQ
M____C;0F`````(GHZ)'^___KD^CY*```+HVT)@````!FD%6)Q5=6B=93Z*G[
M__^!PT^4``"#[#AEH10```")1"0H,<`QP(`Z/0^4P`'&5NB>^/__@\00B40D
M!(U4)!B)Z.C,_/__A<`/A`0!``"#[`R)QU#H>?C__XM,)!2#Q!`YR`^#R@``
M`(M$)!C!X`*)1"0(BX,(`0``B00D#[9%`(3`#X2:`0``/#T/A)(!``")Z`^V
M4`&#P`&$TG0%@/H]=?`IZ(L,)(M\)`B#[`R+5"00`SF-1!`"4.C4]?__@\00
MB0>%P'1*BPPDBWPD"(L!C4T!BQ0X#[9%`(@"/#UU$>L3#[8!@\(!@\$!B`(\
M/70$A,!U[<8"/3'`+HVT)@`````/M@P&B$P"`8/``83)=?&+1"0<92L%%```
M``^%$P$``(/$+%M>7UW#+HVT)@`````QP(VV``````^V%`:(%`>#P`&$TG7R
MZ\<NC;0F`````(N#"`$``(L0B00DBSJ%_P^$P@```#'_+HVT)@````"0B?B#
MQP&+#+J%R77TC02%#````(N+5`$``(7)=6.)5"0,@^P,4,>#5`$```$```#H
M[/3__X/$$(G!A<`/A%[___^-!+T`````@^P$B40D#%"+5"044E&)3"0<Z-'T
M__^+1"00BTPD'(/$$(D(QT2Y!`````")?"08Z8W^__^-=@"#[`A04NC&\___
MB<&+1"00@\00B0B%R0^$`O___XT$O0````")1"0(Z\*-M@`````QP.E[_O__
MN`@````Q_^E0____Z+<F```NC;0F`````%93Z&_Y__^!PQ62``"#[`2-@W3A
M__^+L_P```!0C8,JH?___[,8`0``4&7_-N@.]O__6(V#V:+__UIJ`%!0C8,T
M@?__4(V#1J'__U!E_S;H;//__X/$)%M>PXVV`````%/H$/G__X'#MI$``(/L
M"(V#=.'__U"-@RJA____LQ@!``!0BX/\````9?\PZ*_U__^#Q!A;PRZ-M"8`
M````9I!55U93@>P`$```@PPD`('L`!```(,,)`"#[!SHMOC__X'#7)$``&6A
M%````(F$)`P@```QP.@6\___@^P,C9-;H?__4E"-@U^A__]0:`$0``"-="0F
M5NBU\O__@\0@C5`!@?H!$```#X?3]?__@_C_#X2:````@^P$:``0``"-O"03
M$```5U;H-/3__X/$$(G%A<!X>X/L#(U``5#H#_/__X/$$(G&A<!T9CGX<PN-
M!"@YQP^"A_7__SGW<D.!_0$0```/AW?U__^#[`155U;H_/3__\8$+@"#Q!"+
MA"0,(```92L%%````'4I@<0<(```B?!;7E]=PRZ-M"8`````C00O.<9SMNDT
M]?__C70F`#'VZ\?H]B0``(VT)@````#IV_[__RZ-M"8`````C78`55=64X'L
M`!```(,,)`"![,P```#HC??__X'#,Y```(N\).`0``"+K"3D$```9:$4````
MB80DO!```#'`C40D+(E$)!2)PHV#;:'__^BO^/__@^P(:B^)QE?HXO+__X/$
M$(7`=#.-@W:A__^)^NA^^___B?B+E"2\$```92L5%`````^%J`$``('$S!``
M`%M>7UW#+HUT)@"#[`Q5Z$_R__]:68V+@Z'__XE,)!114.C,\___@\00C8N%
MH?__B<6-@XZB__^)1"08A>UTF(!]``")3"0<#X3V````+HUT)@"%]G05@^P(
M55;H0O'__X/$$(7`#X2S````@^P,5>B^\___@\00B<*-1`7_.<5R$^LDC;0F
M`````,8``(/H`3G%=`6`."]T\8/L#%7HD//__X/$$(G"B50D$(/L#%?H?O/_
M_XM4)""#Q!"-1`(!/?\/```/APW___^#[`A7_W0D*%7_="0L:``0``"-K"38
M````5>AI\/__@\0@@\`!/0`0```/AXKS__^#[`C_="0<5>B+\O__@\00A<!U
M$(M$)#PE`/```#T`@```=%2#[`C_="04:@#HQO+__X/$$(G%A<`/A)[^__^`
M?0``#X4/____A?9T!8`^+G06N@$```"-JVNA___I2____XVV`````(!^`0!T
MMNOB+HVT)@````"#[`AJ`57HQ>___X/$$(7`=9J)ZHV#=J'__^C1^?__@^P,
M5>C(\/__@\00Z43^___HJB(``"Z-M"8`````C78`5E/H7_7__X'#!8X``(/L
M#(MT)!AJ+U;H9/#__X7`C5`!#T7RB30DZ(3P__^#Q!1;7L,NC;0F`````(VV
M`````%93@>P`$```@PPD`(/L%.@2]?__@<.XC0``B[0D(!```&6A%````(F$
M)`P0```QP(7V#X28````@#X`#X2/````@^P,5NCV\?__@\00C5`!,<"!^@`0
M``!W6H/L"%:-="085NC([___B30DZ-#Q__^#Q!"-1`;_.<9R#^L2C78`Q@``
M@^@!.?!T!8`X+W3Q@^P(:B]6Z*;O__^#Q!"%P'0O.<9S`\8``(/L#%;HO^__
M_X/$$(N4)`P0``!E*Q44````=2"!Q!00``!;7L.-=@"#[`R-@VNA__]0Z)'O
M__^#Q!#KT.AV(0``C;0F`````%575N@!$0``@<;4C```4X/L+&6A%````(E$
M)!PQP(U<)!B+K@@!``"-OH>A__^)VHGXZ%GU__^%P'0NBU0D&(M%`(T$D(M0
M!(D0A=)TX&:0BU`(@\`$B1"%TG7TB=J)^.@K]?__A<!UTHNN"`$``(V^D*'_
M_XG:B?CH$O7__X7`="^+5"08BT4`C020BU`$B1"%TG3@C78`BU`(@\`$B1"%
MTG7TB=J)^.CC]/__A<!UT8NN"`$``(V^F*'__XG:B?CHRO3__X7`="^+5"08
MBT4`C020BU`$B1"%TG3@C78`BU`(@\`$B1"%TG7TB=J)^.B;]/__A<!UT8NN
M"`$``(V^H:'__XG:B?CH@O3__X7`="^+5"08BT4`C020BU`$B1"%TG3@C78`
MBU`(@\`$B1"%TG7TB=J)^.A3]/__A<!UT8V&J*'__XN^"`$``(D$)(L$)(G:
MZ#;T__^%P'0LBU0D&(L'C020BU`$B1"%TG3@BU`(@\`$B1"%TG7TBP0DB=KH
M"O3__X7`==2+K@@!``"-OKBA__^)VHGXZ/'S__^%P'0VBU0D&(M%`(T$D(M0
M!(D0A=)TX"Z-M"8`````9I"+4`B#P`2)$(72=?2)VHGXZ+OS__^%P'7*C89M
MH?__B[X(`0``B40D!(M$)`2)VNB<\___A<!T,XM4)!B+!XT$D(M0!(D0A=)T
MWXVV`````(M0"(/`!(D0A=)U](M$)`2)VNAI\___A<!US8V&Q*'__XN^"`$`
M`(E$)`R+1"0,B=KH2O/__X7`=#&+5"08BP>-!)"+4`2)$(72=-^-="8`BU`(
M@\`$B1"%TG7TBT0D#(G:Z!GS__^%P'7/C8;.H?__B[X(`0``B40D"(M$)`B)
MVNCZ\O__A<!T,8M4)!B+!XT$D(M0!(D0A=)TWXUT)@"+4`B#P`2)$(72=?2+
M1"0(B=KHR?+__X7`=<^+K@@!``"-OMBA__^)VHGXZ+#R__^%P'0UBU0D&(M%
M`(T$D(M0!(D0A=)TX"Z-M"8`````D(M0"(/`!(D0A=)U](G:B?CH>_+__X7`
M=<N+K@@!``"-OG:A__^)VHGXZ&+R__^%P'0OBU0D&(M%`(T$D(M0!(D0A=)T
MX(UV`(M0"(/`!(D0A=)U](G:B?CH,_+__X7`==&)VHV&XJ'__^@B\O__A<!T
M"XG"BT0D".@#]?__B=J-AO.A___H!O+__X7`=`V)PHV&!:+__^CE]/__B=J-
MAA"B___HZ/'__XG"A<!T*XM$)`3HR?3__XM$)!QE*P44````=3.+!"2#Q"R-
MEC&B__];7E]=Z:?T__^)VHV&(*+__^BJ\?__A<!TS8G"BT0D#.B+]/__Z\#H
M<QT``(UT)@#H``T```77B```@^P<98L5%````(E4)`PQTHU4)`B-@,2A___H
M9_'__X7`="L/MA"`^C`/E,"$T@^4P@G0@_`!#[;`BU0D#&4K%10```!U#(/$
M',.-="8`,<#KY^@.'0``+HVT)@````"-M"8`````4^C`[___@<-FB```@^P(
MC40D%(/L!%#_="08BX/H````_S#H".O__\<$)/\```#HG.O__RZ-M"8`````
MC70F`%575E.-G"0``/__@>P`$```@PPD`#G<=?*#["SH9>___X'#"X@``(G%
M9:$4````B80D'``!`#'`:@)J`&H`5>BLZ?__@\#_@]+_B40D&(MT)!B)UXE4
M)!S!_Q\Q^"GX,=(E__\``#'Z,?@I^!GZBWPD'"G&B70D&!G7B7PD'(/$$(UT
M)!2%_P^(NP```(UV`&H`_W0D$/]T)!!5Z%#I__^#Q!`AT(/X_P^$M0```(/L
M!&@(``$`5E7H$^O__X/$$(/X_P^$BP```(/X!W92C40&^#GP<DJ-/2@!``#K
M"6:0@^@!.?!R.8L0BT@$,Q0?,TP?!`G*=>DI\)D#1"0($U0D#(N,)!P``0!E
M*PT4````=6"!Q"P``0!;7E]=PXUV`(%$)`@``/__BU0D"(-4)`S_BTPD#(G0
MB<HU``#___?2"=`/A4C___^X_____[K_____ZZZ#[`R-@T"B__]0Z%W^__^#
M[`R-@S.B__]0Z$[^___H2!L``"Z-M"8`````D%/H`.[__X'#IH8``(/L".@L
MZ___@^P,4.BCZ?__@\00A<!T`HL`@\0(6\,NC70F`%575E/HS>W__X'#<X8`
M`(/L+&6A%````(E$)!PQP(U4)!B+;"1`C;M,HO__B?CH_>[__X7`=`>`.`")
MQG4BBT0D'&4K!10```!U;(GJ@\0LB?A;7E]=Z<7Q__\NC70F`(/L#%7HA^K_
M_XDT)(E$)!SH>^K__XM4)!R-1`("B00DZ"OH__^)-"2)PHV#@Z'__U"-@XZB
M__]54%*)5"0LZ!WJ__^#Q""+5"0,BT0D'&4K!10```!TENA3&@``C70F`%57
M5E/H#>W__X'#LX4``('L+`$``(N$)$`!``"-?"0@B?J)1"0,C8MCHO__9@]N
MP8V+&Z+__V6A%````(F$)!P!```QP(V#:Z'__V8/;LF-B_ZA___'A"2X````
M`````&8/;M"-@W"B__]F#V+"9@]NV(V#:*+__\>$).0`````````9@]NX&8/
M8LMF#]:$)+````!F#V[!9@]BQ(V#>:+__XV+=*+__\>$),@`````````9@]L
MP68/;NB-@VVA__\/$80DU````&8/;L%F#V+%B40D&&8/UH0DP````.B-[?__
MA<!T"8`X``^%6`0``.A;Z?__@^P,4.C2Y___@\00A<`/A`<"``"+*(7M#X3]
M`0``@^P,5>@4Z?__@\00@^P,C40``5#HQ.;__X/$$(G&#[9%`(ET)`B$P'0U
MC8N"HO__B7PD!(GOB?6)SHUV`(/L!`^VP(/'`5!658/%`NB<Z/__#[8'@\00
MA,!UXHM\)`2-M"30````C8,%HO__ZQ&-M"8`````BT8$@\8$A<!T+HGZZ-?L
M__^)Q87`=.F`.`!TY.BG[?__A<!TVX/L#%7HJN;__X/$$(G%A<!U,9"-M"2P
M````BRZ%[70C@'T```^$*0$``(GHZ'+M__^%P`^%^@```(MN!(/&!(7M==V#
M[`Q5Z#?H__]:_W0D%(G&Z"OH__^-M`8$!```B30DZ-SE__^)1"04B<%8C8.'
MHO__6O]T)!!0C8.%H?__B40D&%"-@XRB__]5B<U04>B^Y___@\08:,`!``!5
MZ&#G__^#Q!"#^/]U$.A#Y___BP"#^!$/A;("``"#[`A7_W0D$.A;Y___@\00
MB<6%P'44BT0D,"4`\```/0!````/A.T```#_="0$BT0D$/\PC8-`H___4(N#
MZ````/\PZ(#F__^#Q!`Q]HN$)!P!``!E*P44````#X43!```@<0L`0``B?!;
M7E]=PRZ-M"8`````9I"#[`R#Q@15Z'3E__^#Q!")Q87`#X3._O__Z?+^__]F
MD#'MZ>G^__\NC;0F`````)"+A"3`````C;0DP````(7`=""-M@````")^NA!
MZ___A<!T!8`X`'4PBT8$@\8$A<!UYH/L#(VK7*+__VH-Z)[D__^#Q!")QHE$
M)`BX4P```.G8_?__C78`@^P,4.COY/__@\00B<6%P'2^Z93]__^+1"0XB40D
M$.C$YO__.40D$`^%_/[__XM$)#`E_P$``#W``0``#X7H_O__@^P,5N@]Y/__
MB?J)QHV#5Z+__^BNZO__@\00A<`/A*,!``"#[`A0BT0D&/\PZ)3Q__^)1"0@
M@\00A<`/A(4!``"#[`S_="0<Z#GF__^#Q!")PH/X`W8_@^P(C8.5HO__4(M$
M)!R-1!#\B50D*%#H@^/__X/$$(7`=1R+5"0<@_H$#X14`@``BT0D$(!\$/LO
M#X1%`@``B?J-N\2A__^)^.@AZO__A<`/A"D!```/M@"$P`^$'@$``#PP#X06
M`0``C9,QHO__B?B-N]FB___HX^S__^@.X___@^P(5U"-@[FB____="08_W0D
M&%!6Z&3E__^#Q""-@\>B__^)1"0,ZS(NC70F`.CKY/__@S@1=3GHT>+__X/%
M`8/L!%=54/]T)!C_="08_W0D)%;H)N7__X/$((/L"&C``0``5NC%Y/__@\00
M@_C_=+V#[`S_="00Z,'D__^+1"0HB?+H5NS__XDT).@N^O__@\00Z9O]__^#
M[`Q0_W0D%(M$)"#_,(V#!*/__U"+@^@```#_,.CTX___@\0@Z6_]__^-="8`
M@^P,4(E$)!3HZ_G__XM$)!2)!"3H_^+__X/$$(G&Z4K]__\NC70F`(M$)`R+
M`(E$)!#I;/[__Y"#[`AJ`/]T)!SHXN+__X/$$(7`#X31_O__B40D#.CN]___
MB40D$(E4)!2%T@^(N/[__X/`]FH`@]+_4E"+3"0848E,)!SHMN'__X/$#&H&
MC80D]0```%"+3"0848E,)!SH>^/__X/$$(M,)`R#^`8/A>P```"!O"3M````
M`$-!0P^%9/[__V:!O"3Q````2$4/A53^__]J`(M$)!2+5"08@\#.@]+_4E!1
MB4PD'.A.X?__@\0,:BB-O"3[````5XM,)!A1Z!?C__^#Q!"#^"@/A8P```#&
MA"0;`0```(V#V:+__X/L"%"-@ZJB__]7_W0D&/]T)!A05NB#X___@\0@Z6[^
M__^+1"0,BU`$A=(/A*S]__^#[`Q2B50D'.B/X___@\00@_@##X:3_?__@^P(
MC8N:HO__48M4)!B-1`+\4.C;X/__@\00BU0D#(7`#T54)!")5"00Z63]___H
M;A,``(/L#(V#GZ+__U#H8/;__U575E/H'>;__X'#PWX``(/L+&6A%````(E$
M)!PQP(U\)!B)^HNS_````&6++@^V162(166-@ZBA___H0>?__X7`=`F`.#$/
MA$0!``#HG_'__V6++HV#V*+__VH#:@%05>A+X?__@\00B<6%P'0I@^P$C8/:
MHO__4(M%#/\P9?\VZ$OA__^+10R#Q!"+`/9`"D`/A4$!``"-@]^B__]J`VH!
M4&7_-N@&X?__@\00B<6%P'0IB?J-@W:A___HP.;__X7`#X38````@^P$4(M%
M#/\P9?\VZ/?@__^#Q!"#[`2-@^&B__]J`5!E_S;H4-___X/$#(V3]J+__U)0
M9?\VZ,W@__]EBP:)^L9`90"-@VVA___H:>;__X/$$(F#6`$``(7`=#R#[`AH
MP`$``%#HCN'__X/$$(U0`8/Z`78)@_@1#X6F````BT0D'&4K!10````/A<D`
M``"#Q"Q;7E]=PY"#[`S_LUP!``#HHO?__X/$$(F#6`$``(7`=:F#[`R-@Y2C
M__]0Z/;>__^-M@````"`>`$`#X2Z_O__Z:W^__^0Z*OK__^%P'1G@^P$4(M5
M#(E$)!3_,F7_-N@2X/__BT0D'(D$).@&X?__@\00Z0K___^-M@````"#[`A0
M9?\VZ/S>__^#Q!#IJ_[__U"+@UP!``#_LU@!``#_,(V#N*/__U#H>=[__RZ-
MM"8`````D(N#7`$``(/L!/\PZ:S^___H.A$``"Z-M"8`````C78`5U93Z.[C
M__^!PY1\``"#[!!EH10```")1"0,,<"-5"0(BW0D((V#Q*'__^@@Y?__A<!T
M&P^V$(#Z,`^4P(32#Y3""-!U"87V=`6`/@!U&8M$)`QE*P44````=62#Q!!;
M7E_#+HUT)@"#[`Q6Z%_N__^)QUA::B]7Z)/>__^%P(U0`0]%^HD\).BSWO__
M@\0,C9.'HO__:@124.A1WO__@\00A<!UJ8M$)`QE*P44````=0V#Q!")\%M>
M7^D`YO__Z&H0``"+!"3#BS0DPV:0D%575E.)PX'L?`$``(E$)!"-3"0L9:$4
M````B80D;`$``#'`+HUT)@"+5(,<#\J)%(&#P`&#^!!U[XM,)#"+="1@C50D
M-(ML)&2+1"1HB4PD"(V,)#0!``"+7"0LB4PD#.L*C;8`````B4PD"(L*B<>+
M0AB#P@0QR#'PB>Z)_3'8BUPD"-'`B4(T.50D#'79BW0D$(M$)"R+'HM6$(MN
M"(M^#(E4)!R-E`*9>8):B=B+3@3!P`6)_HEL)!0!PHGHB4PD##'XB70D&"'(
MP<D",?B)WP'"B>B)?"0(P<\",<@AV(M<)#`QZ(VT'IEY@EJ)TP'&P<,%`=Z)
MRS'[B=B+7"0T(=#!R@(QR(V<'9EY@EJ+;"0X`<.)\,'`!8V,*9EY@EJ+;"0\
M`<.)^#'0(?#!S@(Q^(V\+YEY@EJ+;"1``<B)V<'!!0'(B=$Q\2'9,=&-E"J9
M>8):BVPD1`'YB<?!QP7!RP(!^8GW,=\AQS'WC;0NF7F"6HML)$@!^HG/P<<%
M`?J)QXG8P<\",?@AR,')`C'8C9PKF7F"6HML)$P!\(G6P<8%`?")SHGY,?$A
MT3'YC;POF7F"6HML)%`!V8G#P<,%`=F)TXGRP<L",=HAPC'RC;0NF7F"6HML
M)%0!^HG/P<<%`?J)QXG8P<\",?@AR,')`C'8C9PKF7F"6HML)%@!\(G6P<8%
M`?")SHGY,?$AT3'YC;POF7F"6HML)%P!V8G#P<,%`=F)TXGRP<L",=HAPC'R
MC;0NF7F"6HML)&`!^HG/P<<%`?J)QXG8P<\",?@AR,')`C'8C9PKF7F"6HML
M)&0!\(G6P<8%`?")SHGY,?$AT3'YC;POF7F"6@'9B</!PP4!V8G3B?+!RP(Q
MVB'"P<@",?*)Q8G8`?J)SS'HP<<%(<C!R0(!^HM\)&@QV(VT/IEY@EJ)UP'P
MP<<%`?B)[S'/B?Z+?"1L(=;!R@(Q[HV\.YEY@EJ)PP'WP<,%BW0D<`'?B<LQ
MTXVT-9EY@EJ+;"1T(</!R`(QRXV,*9EY@EJ+;"1X`=Z)^\'#!0'>B=,QPR'[
M,=/!SP*-E"J9>8):`<N)\<'!!0'+B<$Q^2'QP<X",<$!T8G:P<(%`=&+5"1\
MC800H>O9;HGZ,?(QVL'+`@'"B<C!P`4!PHN$)(````"-O`>AZ]ENB?`QV#'(
M`?B)U\''!0'XB<^+C"2$````P<\"C;0.H>O9;HG9,?DQT<'*`@'QB<;!Q@4!
M\8G6BY0DB````(V<$Z'KV6Z)^C'R,<(!VHG+P<,%`=J)PXN$)(P```#!RP*-
MO`>AZ]ENB?`QV#'(`?B)U\''!0'XB<^+C"20````P<\"C;0.H>O9;HG9,?DQ
MT<'*`@'QB<;!Q@4!\8G6BY0DE````(V<$Z'KV6Z)^C'R,<(!VHG+P<,%`=J)
MPXN$))@```#!RP*-O`>AZ]ENB?`QV#'(`?B)U\''!0'XB<^+C"2<````P<\"
MC;0.H>O9;HG9,?DQT0'QB<;!Q@4!\<'*`HG6BY0DH````(V<$Z'KV6Z)^C'R
M,<(!VHG+P<,%`=J)PXN$)*0```#!RP*-O`>AZ]ENB?`QV#'(`?B)U\''!0'X
MB<^+C"2H````P<\"C;0.H>O9;HG9,?DQT<'*`@'QB<;!Q@4!\8G6BY0DK```
M`(V<$Z'KV6Z)^C'R,<(!VHG+P<,%`=J)PXN$)+````#!RP*-O`>AZ]ENB?`Q
MV#'(`?B)U\''!0'XB<^+C"2T````P<\"C;0.H>O9;HG9,?DQT<'*`@'QB<;!
MQ@4!\8G6BY0DN````(V<$Z'KV6Z)^C'R,<(!VHG+P<,%`=J)PXN$)+P```#!
MRP*-O`>AZ]ENB?`QV#'(`?B)U\''!0'XB<^+C"3`````P<\"C;0.H>O9;HG9
M,?DQT<'*`@'QB<;!Q@4!\8G6BY0DQ````(V<$Z'KV6Z)^C'R,<(!VHG+P<,%
M`=J)PXN$),@```#!RP*)W8V<!Z'KV6Z)\#'H,<@!V(G3P<D"P<,%`=B)ZPG+
MB=^)ZR'7(<O!R@()^XN\),P```"-M#[<O!N/B<<!\\''!8G.`?N)SR'6"=<A
MQ\'(`@G^B[PDT````(V\/=R\&X^)U0'WB=X)Q<'&!2'=P<L"`?>)UB'&">Z+
MK"34````C8PIW+P;CXG=B<,!SHGY">O!P04A^P'.B<$AZ0G9BYPDV````(V<
M&MR\&X^)\@'+P<(%P<\"`=.)Z@GZB=&)ZB'Q(?K!S@()RHN,)-P```"-C`C<
MO!N/B=@!T<'`!8GZ`<$)\HGX(=HA\,'+`@G0BY0DX````(V4%=R\&X\!PHG(
MP<`%`<*)\`G8B<6)\"'-(=@)Z(NL).0```"-O"_<O!N/B=T!^(G7P<<%`?B)
MSXG9P<\""?TA^2'5">F+K"3H````C;0NW+P;CP'QB<;!R@+!Q@4!\8G6B?H)
M\HG5B?HAQ2'R">J+K"3L````C9PKW+P;CP':B<O!PP4!VHG#B?#!RP()V(G%
MB?`AS2'8">B+K"3P````C;POW+P;CXG=`?B)U\''!0'XB<^)V<'/`@G](?DA
MU<'*`@GIBZPD]````(VT+MR\&X\!\8G&P<8%`?&)UHGZ"?*)U8GZ(<4A\@GJ
MBZPD^````(V<*]R\&X\!VHG+P<,%`=J)PXGPP<L""=B)Q8GP(<TAV`GHBZPD
M_````(V\+]R\&X^)W0'XB=?!QP4!^(G/B=G!SP()_2'Y(=7!R@()Z8NL)``!
M``"-M"[<O!N/`?&)QL'&!0'QB=:)^@GRB=6)^B'%(?()ZHNL)`0!``"-G"O<
MO!N/`=J)R\'#!0':B<.)\,'+`HG=B?,)ZR'H(<L)V(N<)`@!``"-G!_<O!N/
M`=B)T\')`L'#!0'8B>L)RXG?B>LAUR'+P<H""?N+O"0,`0``C;0^W+P;CXG'
M`?/!QP6)S@'[B<\AU@G7(<?!R`()_HN\)!`!``"-O#W<O!N/`?Z)W\''!0'^
MB=<)QXG]B=<AW2''P<L"">^+K"04`0``C8PIW+P;CP'YB??!QP4!^8G'"=^)
M_8G'(?4AWPGOBZPD&`$``(V4*MR\&X^+;"0(`?J)S\'.`L''!0'ZB[PD'`$`
M`(V$.-;!8LJ)WS'W,<_!R0(!QXG0P<`%`<>+A"0@`0``C9P#UL%BRHGP,<@Q
MT`'8B?O!PP4!V(G3BY0D)`$``,'+`HV4%M;!8LJ)SC'>,?[!SP(!UHG"P<(%
M`=:+E"0H`0``C8P1UL%BRHG:,?HQPL'(`@'*B?'!P04!RHG!BX0D+`$``(V$
M`];!8LJ)^S'+,?,!PXG0P<`%`<.+A"0P`0``P<X"C;P'UL%BRHG(,?`QT`'X
MB=_!QP4!^(G7BY0D-`$``,'/`HV4$=;!8LJ)\3'Y,=G!RP(!T8G"P<(%`=&+
ME"0X`0``C;06UL%BRHGZ,=HQPL'(`@'RB<[!Q@4!\HG&BX0D/`$``(V$!];!
M8LJ)WS'W,<_!R0(!QXG0P<`%`<>+A"1``0``C9P#UL%BRHGP,<@QT`'8B?O!
MPP4!V(G3BY0D1`$``,'+`HV4%M;!8LJ)SC'>,?[!SP(!UHG"P<(%`=:+E"1(
M`0``C8P1UL%BRHG:,?HQPL'(`@'*B?'!P04!RHG!BX0D3`$``(V$`];!8LJ)
M^S'+,?/!S@(!PXG0P<`%`<.+A"10`0``C;P'UL%BRHG(,?`QT`'XB=_!QP4!
M^(G7BY0D5`$``,'/`HV4$=;!8LJ)\3'Y,=G!RP(!T8G"P<(%`=&+E"18`0``
MC;06UL%BRHGZ,=HQP@'RB<[!R`+!Q@4!\HG&BX0D7`$``(V$!];!8LJ)WS'W
M,<_!R0(!QXG0P<`%`<>+A"1@`0``C9P#UL%BRHGP,<@QT,'*`@'8B?O!PP4!
MV(N<)&0!``"-M![6P6+*B<LQTS'[P<\"`?.)QL'&!0'SB[0D:`$``(VT-=;!
M8LJ)W0'.B='!Q04Q^3'!P<@"`?&+="00C2PIBTPD#&8/;L6+;"04`<N-#"B+
M1"089@]NVV8/;LEF#V+#C0PX9@]NT68/8LIF#VS!#Q$&BT0D'`'0B480BX0D
M;`$``&4K!10```!U"X'$?`$``%M>7UW#Z&0$```NC70F`%/H(-?__X'#QF\`
M`(/L%&I@Z.K1__]F#V^#A.'__[GPX=+#,=N)2!")6!3'0!@`````QT!<````
M``\1`(/$&%O#+HVT)@````"-M"8`````Z*#S__\%=V\``%575E.#[!R+5"0P
MBWPD.(E$)`B+1"0TBUH8C0S]``````-*%(UR'(E*%(GY@],`P>D=`=F)2AB+
M2ER%R71QO4````"-<APIS3G]#T_O`?$YP0^#)P$``(T<*3G8#X+8T___C1PH
MB5PD#(E4)#"#[`154%&+7"08Z$K3__^+5"1`B>B#Q!`#0ER)0ER#^$!T#H/$
M'%M>7UW#C;8`````B=`I[^C_\O__BT0D#(M4)#"#_S\/CH@```"-:$")PXU"
M7(E\)#B)1"0,B>^+;"0XB50D,.M+9I"+1"0,.<,/@A4!``")?"0(\P]O`XM$
M)#"#[4"#PT"#QT`/$0;S#V]+T`\13A#S#V]3X`\15B#S#V];\`\17C#HC/+_
M_X/]/WX7.=YRLXE\)`@Y\W.[.?YSM^D&T___9I"+5"0PBT0D"(GO.<9R*CGP
M<PN-##@YS@^"Y]+__X/_!'-&A?]U>HEZ7(/$'%M>7UW#C;0F`````(T,/CG(
M<][IP-+__XUT)@"-'"B)7"0,.<@/@]S^__\YV0^#U/[__^F@TO__C70F`(L(
MB4H<BTPX_(E,/OR-3@2#X?PISBGP`?Z#YOR#_@1RG8/F_#';BRP8B2P9@\,$
M.?-R\XEZ7.N)#[8(B$H<]\<"````#X1T____#[=$./YFB40^_NEE____Z3[2
M__\NC;0F`````&:055=6Z)'Q__^!QF1M``!3@^P<BUPD-(M\)#"+:QB+2Q0/
MS8GHB<V)!"2)R`_-P>@#B6PD!(UK'(/@/XU0`<9$`QR`@_HX#X[U````N$``
M``"-3!4`*=!T(C'2J`%T#+H!````Q@$`.<)S$,8$$0#&1!$!`(/"`CG"<O")
MV.@?\?__9@_OP`\10QP/$44@#Q%%$`\112CS#WX,)(G89@_62U3H^O#__XL#
M@^P,P>@8B`>+`\'H$(A'`8L#B&<"BP.(1P,/MD,'B$<$#[=#!HA'!8M#!(AG
M!HM#!(A'!P^V0PN(1P@/MT,*B$<)BT,(B&<*BT,(B$<+#[9##XA'#`^W0PZ(
M1PV+0PR(9PZ+0PR(1P\/MD,3B$<0#[=#$HA'$8M#$(AG$HM#$(A'$U.)\^@^
MT/__@\0L6UY?7<.-M@````"X.````(U,%0`IT(/X!`^"C````(U1!,<!````
M`(/B_,=$`?P`````*=$!R(/@_(/X!`^"'?___XG!C6C_@^'\P>T"B4PD#+D$
M````@^4!QP(`````.<$/@_C^__^%[708QT($`````(M$)`RY"````#G!#X/<
M_O__BT0D#,<$"@````#'1`H$`````(/!"#G!<NKIO?[__RZ-M"8`````A<`/
MA*W^___&`0"H`@^$HO[__S'29HE4`?[IEO[__U6)Y5/HOM+__X'#9&L``%#H
MW,___UI;7<.#[`R#Q`S#````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````E<R\E<P!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`26YT97)N
M86QS.CI005(Z.D)/3U0`97AE`"]P<F]C+R5I+R5S`"X`4$%27U1%35``4$%2
M7U!23T=.04U%`#H`+P!015),-4Q)0@!015),3$E"`%!%4DPU3U!4`%!%4DQ)
M3P!005)?24Y)5$E!3$E:140`4$%27U-005=.140`4$%27T-,14%.`%!!4E]$
M14)51P!005)?0T%#2$4`4$%27T=,3T)!3%]$14)51P!005)?1TQ/0D%,7U1-
M4$1)4@!005)?5$U01$E2`%!!4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,
M14%.`#$`;'-E96L@9F%I;&5D`')E860@9F%I;&5D`$Q$7TQ)0E)!4EE?4$%4
M2`!365-414T`+W1M<`!414U01$E2`%1-4`!54T52`%5315).04U%`"4P,G@`
M<&%R+0`E<R5S)7,E<P!P87)L`"YP87(`<VAO<G0@<F5A9``E<R5S8V%C:&4M
M)7,E<P`E<R5S=&5M<"TE=25S`"5S)7-T96UP+25U+25U)7,`&`!P97)L`#``
M4$%2.CI086-K97(Z.E9%4E-)3TX`,2XP-C,`+64`+2T````E<SH@8W)E871I
M;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE
M:2D*```E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP
M;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*``!5
M;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R>0`````E<SH@8W)E871I
M;VX@;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE
M<G)N;STE:2D*`````&5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@
M)'LQ*R(D0")])PII9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE
M;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1005)?34%'24,L("1&24Q%7V]F
M9G-E=%]S:7IE+"`D8V%C:&5?;F%M95]S:7IE*3L*0D5'24X@>PHD4$%27TU!
M1TE#(#T@(EQN4$%2+G!M7&XB.PHD1DE,15]O9F9S971?<VEZ92`](#0[("`@
M(R!P86-K*").(BD*)&-A8VAE7VYA;65?<VEZ92`](#0P.PHD4$M:25!?34%'
M24,@/2`B4$M<,#`S7#`P-"(["GT*<W5B(&9I;F1?<&%R7VUA9VEC"GL*;7D@
M*"1F:"D@/2!`7SL*;7D@)&-H=6YK7W-I>F4@/2`V-"`J(#$P,C0["FUY("1B
M=68["FUY("1S:7IE(#T@+7,@)&9H.PIM>2`D<&]S(#T@*"1S:7IE+3$I("T@
M*"1S:7IE+3$I("4@)&-H=6YK7W-I>F4[("`@("`@(R!.3U1%.B`D<&]S(&ES
M(&$@;75L=&EP;&4@;V8@)&-H=6YK7W-I>F4*=VAI;&4@*"1P;W,@/CT@,"D@
M>PIS965K("1F:"P@)'!O<RP@,#L*<F5A9"`D9F@L("1B=68L("1C:'5N:U]S
M:7IE("L@;&5N9W1H*"1005)?34%'24,I.PII9B`H*&UY("1I(#T@<FEN9&5X
M*"1B=68L("1005)?34%'24,I*2`^/2`P*2!["G)E='5R;B`D<&]S("L@)&D[
M"GT*)'!O<R`M/2`D8VAU;FM?<VEZ93L*?0IR971U<FX@+3$["GT*;7D@*"1P
M87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92P@)4UO9'5L94-A8VAE*3L*
M14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E
M;7`["G)E<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E
M8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?
M=&5M<"D["F]U=',H<7%;4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")=
M*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER
M(#H@=6YL:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@
M*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@
M/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2
M(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@
M/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*;7D@)&9I;&5N86UE(#T@)'1M
M<"T^9FEL96YA;64["G!R:6YT("1T;7`@/#PB+BXN(CL*>#TQ.R!W:&EL92!;
M(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@
M+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X
M<'(@7"1X("L@,6`*9&]N90IR;2`G)&9I;&5N86UE)PHN+BX*8VQO<V4@)'1M
M<#L*8VAM;V0@,#<P,"P@)&9I;&5N86UE.PIM>2`D8VUD(#T@(B1F:6QE;F%M
M92`^+V1E=B]N=6QL(#(^)C$@)B(["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<5M3
M<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z
M("1F:6QE;F%M95TI.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2.CI"
M3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["F5V86P@
M>PI?<&%R7VEN:71?96YV*"D["FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)5
M1WT["FUY("5S>7,@/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I
M;B\@/R`G.R<@.B`G.B<I+`I?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z
M35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@
M("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?
M<V5T7W!R;V=N86UE*"D["F]U=',H<7%;7"1P<F]G;F%M92`]("(D<')O9VYA
M;64B72D["E]S971?<&%R7W1E;7`H*3L*;W5T<RAQ<5M<)$5.5GM005)?5$5-
M4'T@/2`B)$5.5GM005)?5$5-4'TB72D["FUY("@D<W1A<G1?<&]S+"`D<W1A
M<G1?;V9?1DE,15]S96-T:6]N*3L*34%'24,Z('L*;&]C86P@)%-)1WM?7U=!
M4DY?7WT@/2!S=6(@>WT["G5N;&5S<R`H;W!E;B!?1D@L("<\.G)A=R<L("1P
M<F]G;F%M92D@>PIO=71S*'%Q6T-A;B=T(')E860@9G)O;2!F:6QE("(D<')O
M9VYA;64B72D[("`C(&1O;B=T('5S92`D(2!H97)E(&%S(&ET(')E<75I<F5S
M($5R<FYO+G!M"FQA<W0@34%'24,["GT*;7D@)&UA9VEC7W!O<R`](&9I;F1?
M<&%R7VUA9VEC*"I?1D@I.PII9B`H)&UA9VEC7W!O<R`\(#`I('L*;W5T<RAQ
M<5M#86XG="!F:6YD(&UA9VEC('-T<FEN9R`B)%!!4E]-04=)0R(@:6X@9FEL
M92`B)'!R;V=N86UE(ETI.PIL87-T($U!1TE#.PI]"F]U=',H(D9O=6YD(%!!
M4B!M86=I8R!A="!P;W-I=&EO;B`D;6%G:6-?<&]S(BD["G-E96L@7T9(+"`D
M;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4@+2!L96YG=&@H(EPP0T%#
M2$4B*2P@,#L*<F5A9"!?1D@L("1B=68L(&QE;F=T:"@B7#!#04-(12(I.PII
M9B`H)&)U9B!N92`B7#!#04-(12(@)B8@)&)U9B!N92`B7#!#3$5!3B(I('L*
M;W5T<R@B3F\@8V%C:&4@;6%R:V5R(&9O=6YD(BD["FQA<W0@34%'24,["GT*
M;W5T<RAQ<5M#86-H92!M87)K97(@(B1B=68B(&9O=6YD72D["G-E96L@7T9(
M+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4L(#`["G)E860@7T9(
M+"`D8G5F+"`D1DE,15]O9F9S971?<VEZ93L*;7D@)&]F9G-E="`]('5N<&%C
M:R@B3B(L("1B=68I.PIO=71S*")/9F9S970@9G)O;2!S=&%R="!O9B!&24Q%
M<R!I<R`D;V9F<V5T(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?
M;V9F<V5T7W-I>F4@+2`D;V9F<V5T+"`P.PHD<W1A<G1?;V9?1DE,15]S96-T
M:6]N(#T@=&5L;"!?1D@["FUY("5R97%U:7)E7VQI<W0["G)E860@7T9(+"`D
M8G5F+"`T.R`@("`@("`@("`@("`@("`@("`@("`@("`@(",@<F5A9"!T:&4@
M9FER<W0@(D9)3$4B"G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&
M2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I
M.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q6U5N<&%C:VEN9R!&24Q%
M("(D9G5L;&YA;64B+BXN72D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S
M?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S96YA
M;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*
M<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB
M+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z
M<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D
M8W)C)&5X="(L("1B=68L(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE
M>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B1005(Z.DAE879Y.CI&=6QL0V%C
M:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*?0IE;'-E('L*)$UO9'5L94-A
M8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*
M;F%M92`]/B`D9G5L;&YA;64L"GT["B1R97%U:7)E7VQI<W1[)&9U;&QN86UE
M?2LK.PI]"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B
M('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F("1M
M;V1U;&4@;W(@(21M;V1U;&4["FUY("1I;F9O(#T@)$UO9'5L94-A8VAE>R1M
M;V1U;&5].PIR971U<FX@=6YL97-S("1I;F9O.PID96QE=&4@)')E<75I<F5?
M;&ES='LD;6]D=6QE?3L*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1I;F9O
M+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)
M3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I
M;&4@;W(@9&EE(")#86XG="!C<F5A=&4@=&5M<"!F:6QE.B`D(2(["B1F:"T^
M8FEN;6]D92@I.PHD9F@M/G!R:6YT*"1I;F9O+3Y[8G5F?2D["B1F:"T^<V5E
M:R@P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@
M7W-A=F5?87,H(B1I;F9O+3Y[8W)C?2YP;2(L("1I;F9O+3Y[8G5F?2D["B1I
M;F9O+3Y[9FEL97T@/2`D9FEL96YA;64["F]P96X@;7D@)&9H+"`G/#IR87<G
M+"`D9FEL96YA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE;F%M92(Z
M("0A73L*<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D
M.B!C86XG="!F:6YD(&UO9'5L92`D;6]D=6QE(2(["GTL($!)3D,I.PIR97%U
M:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R
M<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y
M.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE
M("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=
M*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O
M0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q
M=6ER92`D9FEL96YA;64["GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@
M)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E
M("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0II9B`H)&)U9B!N92`D4$M:
M25!?34%'24,I('L*;W5T<RAQ<5M.;R!Z:7`@9F]U;F0@869T97(@1DE,12!S
M96-T:6]N(&EN(&9I;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-04=)0R`["GT*
M)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.R`@("`@("`@("`@("`@("`C
M('-T87)T(&]F('II<`I]"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD
M;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?05!0
M7U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@
M<')O8FQE;2D*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G+2UP
M87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]('%W*`IP
M("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN<W1A;&Q?
M<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H0$%21U8@
M86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`05)'5CL*)$5.
M5GM005)?05!07U)%55-%?2`]('-H:69T($!!4D=6.PI]"F5L<V4@>R`C(&YO
M<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI;&4@*$!!
M4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO
M(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*<'5S:"!`861D7W1O7VEN8RP@
M)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B.PI]"F5L
M<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`<&%R7V%R9W,L("0R.PI]"F5L
M<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R.PI]"F5L<VEF("@D,2!E<2`G
M8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE;'-I9B`H)#$@97$@)T(G*2![
M"B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G*2!["B1Q=6EE
M="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F:"P@(CX^
M(BP@)#(@;W(@9&EE('%Q6T-A;B=T(&]P96X@;&]G(&9I;&4@(B0R(CH@)"%=
M.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*?0IS
M:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PID
M96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER92!0
M05(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6
M.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET.PI]
M"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T*2![
M"GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E
M<75I<F4@1&EG97-T.CI32$$["GT*;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*
M;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1F:"P@)SPZ
M<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@9FEN9"!P87(@9FEL92`B)'!A
M<B(Z("0A73L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI
M=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L
M("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92!Q<5M%
M<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D<&%R(ET["GT*;7D@)6UE=&%?
M<&%R(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT
M96YT<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*
M)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H
M+BLI)"]M9SL*?0I].PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)'!H
M+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!R96%D('!A<B!F:6QE
M("(D<&%R(CH@)"%=.PIM>2`D8G5F.PIR96%D("1P:"P@)&)U9BP@-#L*9&EE
M('%Q6R(D<&%R(B!I<R!N;W0@82!P87(@9FEL95T@=6YL97-S("1B=68@97$@
M)%!+6DE07TU!1TE#.PIC;&]S92`D<&@["GT*0W)E871E4&%T:"@D;W5T*2`[
M"FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-2
M14%4*"D@?"!)3SHZ1FEL93HZ3U]21%=2*"D@?"!)3SHZ1FEL93HZ3U]44E5.
M0R@I+`HP-S<W+`HI(&]R(&1I92!Q<5M#86XG="!C<F5A=&4@9FEL92`B)&]U
M="(Z("0A73L*)&9H+3YB:6YM;V1E*"D["G-E96L@7T9(+"`P+"`P.PIM>2`D
M;&]A9&5R.PII9B`H9&5F:6YE9"`D<W1A<G1?;V9?1DE,15]S96-T:6]N*2![
M"G)E860@7T9(+"`D;&]A9&5R+"`D<W1A<G1?;V9?1DE,15]S96-T:6]N.PI]
M(&5L<V4@>PIL;V-A;"`D+R`]('5N9&5F.PHD;&]A9&5R(#T@/%]&2#X["GT*
M:68@*"$D14Y6>U!!4E]615)"051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC
M(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI0
M05(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD;&]A9&5R+"`D,"D["GT*
M)&9H+3YP<FEN="@D;&]A9&5R*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!L
M;V%D97(@=&\@(B1O=70B.B`D(5T["FEF("@D8G5N9&QE*2!["G)E<75I<F4@
M4$%2.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII
M;FET7VEN8R@I.PIR97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@
M>R`A+T)31%!!3B\@?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH
M)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D
M0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["G-\+RM\+WQG
M+"!S?"\D?'P@9F]R96%C:"!`:6YC.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK
M*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU97,@
M)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T[
M("`@("`@("`@(R!86%@@;&EB7V5X="!V<R!D;&5X="`_"FUY("5W<FET=&5N
M.PIF;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1F
M:6QE+"`D;F%M92D["FEF("AD969I;F5D*&UY("1F8R`]("1005(Z.DAE879Y
M.CI&=6QL0V%C:&5[)&ME>7TI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL
M("1F8RD["GT*96QS92!["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H
M)&ME>2`]?B!M?%Y<421D:7)<12\H+BHI)'QI*2!["B@D9FEL92P@)&YA;64I
M(#T@*"1K97DL("0Q*3L*;&%S=#L*?0II9B`H)&ME>2`]?B!M?%XO;&]A9&5R
M+UM>+UTK+R@N*BDD?"D@>PII9B`H;7D@)')E9B`]("1-;V1U;&5#86-H97LD
M,7TI('L**"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"FEF
M("@M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B
M+"`D,2D["FQA<W0["GT*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M
M93L*;F5X="!I9B`D=W)I='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F
M:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"]I.PIO=71S*'-P
M<FEN=&8H<7%;4&%C:VEN9R!&24Q%("(E<R(N+BY=+"!R968@)&9I;&4@/R`D
M9FEL92T^>VYA;65](#H@)&9I;&4I*3L*;7D@)&-O;G1E;G0["FEF("AR968H
M)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIL
M;V-A;"`D+R`]('5N9&5F.PIO<&5N(&UY("1T:"P@)SPZ<F%W)RP@)&9I;&4@
M;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE(CH@)"%=.PHD8V]N=&5N="`]
M(#PD=&@^.PIC;&]S92`D=&@["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P
M;'DH7"1C;VYT96YT+"`B/&5M8F5D9&5D/B\D;F%M92(I"FEF("$D14Y6>U!!
M4E]615)"051)37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*
M4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E
M;G0L("1F:6QE+"`D;F%M92D["GT*)&9H+3YP<FEN="@B1DE,12(L"G!A8VLH
M)TXG+"!L96YG=&@H)&YA;64I("L@.2DL"G-P<FEN=&8H(B4P.'@O)7,B+"!!
M<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE*2P*
M<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI+`HD8V]N=&5N="D*;W(@9&EE
M('%Q6T5R<F]R('=R:71I;F<@96UB961D960@1DE,12!T;R`B)&]U="(Z("0A
M73L*;W5T<RAQ<5M7<FET=&5N(&%S("(D;F%M92)=*3L*?0I]"FEF("@D>FEP
M*2!["B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@/3T@07)C:&EV93HZ
M6FEP.CI!6E]/2PIO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!Z:7`@<&%R="!O
M9B`B)&]U=")=.PI]"FEF("@D;65T85]P87)[8VQE86Y]*2!["B1F:"T^<')I
M;G0H(EPP0TQ%04XB*3L*?0IE;'-E('L*:68@*"%D969I;F5D("1C86-H95]N
M86UE*2!["FUY("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIS965K("1F
M:"P@,"P@,#L*)&-T>"T^861D9FEL92@D9F@I.PIS965K("1F:"P@,"P@,CL*
M)&-A8VAE7VYA;64@/2`D8W1X+3YH97AD:6=E<W0["GT*)&-A8VAE7VYA;64@
M/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L("1C86-H95]N86UE7W-I>F4["B1C
M86-H95]N86UE("X](")<,"(@>"`H)&-A8VAE7VYA;65?<VEZ92`M(&QE;F=T
M:"`D8V%C:&5?;F%M92D["B1F:"T^<')I;G0H)&-A8VAE7VYA;64L"B)<,$-!
M0TA%(BD["GT*;7D@)&]F9G-E="`]("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A
M9&5R*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@)&]F9G-E="DL"B1005)?34%'
M24,I.PHD9F@M/F-L;W-E(&]R(&1I92!Q<5M%<G)O<B!W<FET:6YG('1R86EL
M97(@;V8@(B1O=70B.B`D(5T["F-H;6]D(#`W-34L("1O=70["F5X:70["GT*
M>PIL87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA
M;64H*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D
M97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ
M6FEP.PI]"FUY("1F:"`]($E/.CI&:6QE+3YN97<[("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`C($%R8VAI=F4Z.EII<"!O<&5R871E<R!O;B!A;B!)
M3SHZ2&%N9&QE"B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I
M92!Q<5MF9&]P96XH*2!F86EL960Z("0A73L*07)C:&EV93HZ6FEP.CIS971#
M:'5N:U-I>F4H+7,@7T9(*3L*;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W
M.PHH)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]
M/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI"F]R(&1I92!Q<5M%<G)O<B!R96%D
M:6YG('II<"!A<F-H:79E("(D<')O9VYA;64B73L*07)C:&EV93HZ6FEP.CIS
M971#:'5N:U-I>F4H-C0@*B`Q,#(T*3L*<'5S:"!`4$%2.CI,:6)#86-H92P@
M)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["F]U=',H
M(D5X=')A8W1I;F<@>FEP+BXN(BD["FEF("AD969I;F5D("1%3E9[4$%27U1%
M35!]*2![(",@<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H
M(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB
M97(M/FES1&ER96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF
M:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S
M:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI
M"B0*?7@["FUY("1E>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]
M($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T
M7VYA;64I.PII9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M
M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q6U-K:7!P:6YG("(D;65M
M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N
M86UE(ETI.PI](&5L<V4@>PIO=71S*'%Q6T5X=')A8W1I;F<@(B1M96UB97)?
M;F%M92(@=&\@(B1D97-T7VYA;64B+BXN72D["B@D;65M8F5R+3YE>'1R86-T
M5&]&:6QE3F%M960H)&1E<W1?;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/
M2R@I*0IO<B!D:64@<7%;17)R;W(@97AT<F%C=&EN9R!Z:7`@;65M8F5R('1O
M("(D9&5S=%]N86UE(ET["F-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>
M3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD
M<')O9VYA;65]*2!["F1I92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@
M)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C
M+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE
M72!S<F,N<&%R"BX*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@
M)#`@/2!S:&EF="A`05)'5BD["GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA
M;64I(#T@0%\["G)E<75I<F4@1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA
M;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H
M)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0
M871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H
M(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U
M:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97([
M"G)E<75I<F4@<W1R:6-T.PIR97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A
M<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER
M92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP
M;W)T97(["G)E<75I<F4@1F-N=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q
M=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O
M;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR
M97%U:7)E($-O;7!R97-S.CI:;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*
M<F5Q=6ER92!$:6=E<W0Z.E-(03L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2
M.CI(96%V>3L*<F5Q=6ER92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT
M97(Z.E!O9%-T<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E
M;G0["G)E<75I<F4@871T<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D('T[
M"F5V86P@>R!R97%U:7)E(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA
M<CHZ571I;"!].PIE=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R
M<W0@?3L*979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@
M?3L*979A;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A
M;&%R('T["F5V86P@>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?
M=&5M<"!["FEF("AD969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!
M4E]414U0?2`]?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*
M?0IF;W)E86-H(&UY("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]4
M35!$25(@5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-
M4"`O=&UP("X@*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@
M+60@)'!A=&@@86YD("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I
M9#L*979A;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D
M/CM].PII9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E
M<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D
M<'=U:60I('L*)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA
M;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG
M.PI]"FUY("1S=&UP9&ER(#T@(B1P871H)'-Y<WM?9&5L:6U]<&%R+2(N=6YP
M86-K*")(*B(L("1U<V5R;F%M92D["FUK9&ER("1S=&UP9&ER+"`P-S4U.PIM
M>2`D8V%C:&5?9&ER.PII9B`H)$5.5GM005)?0TQ%04Y]*2!["B1C86-H95]D
M:7(@/2`B=&5M<"TD)"(["GT*96QS92!["F]P96X@;7D@)&9H+"`B/#IR87<B
M+"`D<')O9VYA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1P<F]G;F%M92(Z
M("0A73L*:68@*"AM>2`D;6%G:6-?<&]S(#T@9FEN9%]P87)?;6%G:6,H)&9H
M*2D@/CT@,"D@>PIS965K("1F:"P@)&UA9VEC7W!O<PHM("1&24Q%7V]F9G-E
M=%]S:7IE"BT@;&5N9W1H*")<,$-!0TA%(BDL(#`["FUY("1B=68["G)E860@
M)&9H+"`D8G5F+"!L96YG=&@H(EPP0T%#2$4B*3L*:68@*"1B=68@97$@(EPP
M0T%#2$4B*2!["G-E96L@)&9H+"`D;6%G:6-?<&]S"BT@)$9)3$5?;V9F<V5T
M7W-I>F4*+2!L96YG=&@H(EPP0T%#2$4B*0HM("1C86-H95]N86UE7W-I>F4L
M(#`["G)E860@)&9H+"`D8G5F+"`D8V%C:&5?;F%M95]S:7IE.PHD8G5F(#U^
M(',O7#`O+V<["B1C86-H95]D:7(@/2`B8V%C:&4M)&)U9B(["GT*?0IC;&]S
M92`D9F@["GT*:68@*"$D8V%C:&5?9&ER*2!["B1C86-H95]D:7(@/2`B=&5M
M<"TD)"(["B1%3E9[4$%27T-,14%.?2`](#$["GT*)'-T;7!D:7(@+CT@(B1S
M>7-[7V1E;&EM?21C86-H95]D:7(B.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*
M)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;&%S=#L*?0HD<&%R7W1E;7`@
M/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@
M+R@N*RDO.PI]"G-U8B!?<V%V95]A<R!["FUY("@D;F%M92P@)&-O;G1E;G1S
M+"`D;6]D92D@/2!`7SL*;7D@)&9U;&QN86UE(#T@(B1P87)?=&5M<"\D;F%M
M92(["G5N;&5S<R`H+64@)&9U;&QN86UE*2!["FUY("1T96UP;F%M92`]("(D
M9G5L;&YA;64N)"0B.PIM>2`D9F@["BAO<&5N("1F:"P@)SXZ<F%W)RP@)'1E
M;7!N86UE*0HF)B`H<')I;G0@)&9H("1C;VYT96YT<RD*)B8@*&-L;W-E("1F
M:"D*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@(B1T96UP;F%M92(Z("0A73L*
M8VAM;V0@)&UO9&4L("1T96UP;F%M92!I9B!D969I;F5D("1M;V1E.PIR96YA
M;64H)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M<&YA;64I
M.PI]"G)E='5R;B`D9G5L;&YA;64["GT*<W5B(%]S971?<')O9VYA;64@>PII
M9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!2
M3T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R;V=N
M86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O
M9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]('-U
M8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM
M?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D
M<')O9VYA;64L("1S>7-[7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E;B!M>2`D
M9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I9B`M<R`D9F@["GT*:68@
M*"US("(D<')O9VYA;64D<WES>U]E>&5](BD@>PHD<')O9VYA;64@+CT@)'-Y
M<WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI="`O
M7%$D<WES>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT(&EF(&5X
M:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0
M?3L*)&1I<B`]?B!S+UQ1)'-Y<WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE
M(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64D<WES>U]E>&5](BDL(&QA
M<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE
M?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B
M*2P@;&%S="D*:68@+7,@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B.PI]
M"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.
M5GM005)?4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D<WES>U]D
M96QI;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1S>7-[7V1E;&EM?21P<F]G
M;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#
M=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I
M;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M
M92`]?B!S+UXH/SU<+EPN/UQ1)'-Y<WM?9&5L:6U]7$4I+R1P=V0D<WES>U]D
M96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*<W5B
M(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK
M(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)5$E!3$E:
M141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@
M0T%#2$4@4%)/1TY!344@*2`I('L*9&5L971E("1%3E9[(E!!4E\D7R)].PI]
M"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I('L*)$5.5GLB
M4$%27R1?(GT@/2`D14Y6>R)005)?1TQ/0D%,7R1?(GT@:68@97AI<W1S("1%
M3E9[(E!!4E]'3$]"04Q?)%\B?3L*?0II9B`H)$5.5GM005)?5$5-4'TI('L*
M9&5L971E("1%3E9[4$%27T-,14%.?3L*?0I]"G-U8B!O=71S('L*<F5T=7)N
M(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB
M.PI]"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR
M97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D
M0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP
M('-I=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L
M:6)E>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T
M($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S
M*3L*9&EE('%Q6W!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R
M;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN70IU;FQE<W,@
M+64@)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF
M("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*
M?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF
M("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z
M.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH``$-!0TA%``!P
M97)L>'-I+F,``````````2-%9XFKS>_^W+J8=E0R$`$;`SL0`0``(0```*!_
M__\L`0``$(/__U`!```P@___;`0``#*#__^@!0``-(/__Q@-``!`@___V`L`
M`""'__]D`0```(C__]P!``"0B/__*`(``!"*___8`@``4(S__U@#``"PC/__
MJ`,``/",___4`P``$([__X@$```@CO__G`0``&"0__^\!0``H)#__^P%``"0
MD?__9`8``)"5__^D!@```);__\`&``!`EO__Z`8``,"7__^8!P``\)?__\0'
M``"PF/__&`@``*"?__^$"@``T*'__VP+``"5HO__(`P``)FB__\T#```H*+_
M_T@,``"@KO__C`P``/"N__^P#````+'__S0-``#_LO__A`T``!0`````````
M`7I2``%\"`$;#`0$B`$``"`````<````;'[__W`#````#@A&#@Q*#PMT!'@`
M/QH[*C(D(A````!`````N('__Q@`````````=````%0```"TA?__W`````!!
M#@B%`D$.#(<#00X0A@1!#A2#!4X.,`))#C1!#CA$#CQ!#D!(#C!9"@X40\,.
M$$'&#@Q!QPX(0<4.!$@+=`H.%$/##A!!Q@X,0<<."$'%#@1&"T,.%$/##A!#
MQ@X,0<<."$'%#@0`2````,P````<AO__D`````!!#@B&`D,.#(,#40ZX`50.
MO`%!#L`!2`ZP`6$.N`%"#KP!00[``4@.L`%J"@X,0<,."$'&#@1!"P```*P`
M```8`0``8(;__W8!````00X(A0)!#@R'`T$.$(8$0PX4@P51#M`!<@H.%$'#
M#A!!Q@X,0<<."$'%#@1#"T,.W`%!#N`!2`[0`4D.W`%!#N`!2`[0`6L.W`%!
M#N`!<`[D`4$.Z`%!#NP!00[P`4@.V`%%#MP!00[@`4@.T`%8#MP!00[@`4@.
MT`%##MP!00[@`4@.T`%##MP!00[@`4@.T`%/#MP!00[@`5`.T`$`?````,@!
M```PA___.`(```!!#@B%`D,.#(<#00X0A@1##A2#!4X.3%<.4$@.0%H.3$,.
M4$P.0`).#DQ+#E!(#D`"9`H.%$'##A!!Q@X,0<<."$'%#@1)"P)D#DQ!#E!2
M#D!4#D1%#DA%#DQ!#E!4#D!9#DA!#DQ!#E!.#D````!,````2`(``/"(__]:
M`````$$."(8"00X,@P-.#A!-#A1,#AA!#AQ##B!&#AQ'#AA"#AQ!#B!!#B1'
M#BA'#BQ##C!(#@Q!PPX(0<8.!````"@```"8`@```(G__S8`````00X(@P).
M#A!'#A1,#AA!#AQ)#B!(#@A!PPX$E````,0"```4B?__&0$```!!#@B%`D$.
M#(<#00X0A@1!#A2#!48.E"!*#I1`1PZP0&(.O$!'#L!`00[$0$<.R$!%#LQ`
M10[00$@.L$!;#K1`10ZX0$@.O$!!#L!`2`ZP0$D.O$!$#L!`2`ZP0&@.M$!!
M#KA`00Z\0$$.P$!,#K!`5@H.%$/##A!!Q@X,0<<."$'%#@1)"P`8````7`,`
M`+Q^__\"``````ZP0(,%A0*&!(<#$````'@#``"`B?__!0```````````0``
MC`,``'R)__\U`@```$$."(4"00X,AP-!#A"&!$$.%(,%1@Z4($H.X"$"0`[H
M(4(.["%##O`A2`[@(6T*#A1!PPX00<8.#$''#@A!Q0X$1@M##NPA00[P(48.
M["%!#N@A2P[L(4$.\"%(#N`A<`[H(4$.["%!#O`A2`[@(4L.["%!#O`A2`[@
M(64.["%!#O`A2`[@(4D.["%!#O`A3`[@(5(.Z"%!#NPA1`[P(4$.]"%$#O@A
M10[\(4@.@")(#N`A40[H(40.["%!#O`A2`[@(5<.Z"%$#NPA0@[P(4@.X"$"
M1@[H(4(.["%!#O`A2`[@(50.["%!#O`A2`[@(0```!@```"0!```BGW__P(`
M````#N`A@P6%`H8$AP,L````K`0``)R*__\R`````$$."(8"00X,@P-.#AA&
M#AQ!#B!8#@Q!PPX(0<8.!`!T````W`0``*R*___I`````$$."(8"00X,@P-&
M#HP@1PZ@('4.K"!!#K`@2`Z@(%`.J"!!#JP@10ZP(%`.H"!?#J@@0@ZL($$.
ML"!(#J`@3@ZL($$.L"!(#J`@5@H.#$'##@A!Q@X$1`M##JP@1PZP($@.H"``
M```\````5`4``"2+___\`P```$$."(4"00X,AP-!#A"&!$P.%(,%0PY``[@#
M"@X41\,.$$'&#@Q!QPX(0<4.!$4+&````)0%``#DCO__80````!-#B`"1@H.
M!$4+`"0```"P!0``.(___S0`````00X(@P).#A!'#A1!#AA$#AQ(#B````"L
M````V`4``%"/__]W`0```$$."(4"00X,AP-!#A"&!$$.%(,%1PP#E(`$3@T$
M0P[`@`1>#L2`!$(.R(`$0@[,@`1!#M"`!`)"#L"`!%$.Q(`$1`[(@`1$#LR`
M!$$.T(`$2`[`@`1.#L2`!$4.R(`$00[,@`1!#M"`!$@.P(`$`E@*#A1!PPX0
M0<8.#$''#@A!Q0X$1`MW"@[,@`1'#M"`!$4+0PH.S(`$1P[0@`1%"R@```"(
M!@``()#__RL`````00X(@P).#A!(#AQ!#B!(#A!)#@A!PPX$````4````+0&
M```DD/__O`````!!#@B%`D$.#(<#00X0A@1!#A2#!4X.0'X*#A1#PPX00<8.
M#$''#@A!Q0X$2@M##DQ!#E!M#E1'#EA!#EQ!#F!,#D``:`(```@'``"0D/__
M\`8```!!#@B%`D$.#(<#00X0A@1!#A2#!5$.P`("XP[,`D$.T`)(#L`"50[,
M`D$.T`)(#L`"0P[,`D4.T`)(#L`"9`[$`D<.R`)!#LP"00[0`DX.P`("1@[,
M`D$.T`)(#L`">@[,`D$.T`)&#LP"1`[0`ET.S`)'#L@"1`[,`D$.T`)+#M0"
M1P[8`D,.W`)!#N`"2`[(`D4.S`)!#M`"2`[``E@.R`)!#LP"1`[0`D@.P`)>
M#L0"1@[(`D<.S`)(#M`"2`[``EP*#A1#PPX00<8.#$''#@A!Q0X$2PM##LP"
M1`[0`D@.P`("5@[,`D@.T`)(#L`"5@[,`D$.T`)(#L`">0[,`D$.T`)7#L`"
M2P[(`D$.S`)&#M`"3`[``DL.S`)$#M`"2`[``DH.R`)'#LP"30[0`D@.P`("
M90[(`D$.S`)!#M`"2@[4`D0.V`)!#MP"00[@`D@.P`)F#L0"00[(`D$.S`)!
M#M`"1`[4`D0.V`)$#MP"00[@`D@.P`)##L@"10[,`D$.T`)(#L`"2`[,`D0.
MT`);#L`"2`[,`D$.T`)$#M0"1@[8`D<.W`)(#N`"2`[``DP.S`)!#M`"6`[`
M`E\.R`)"#LP"1`[0`D@.P`)F#L0"1`[(`D$.S`)%#M`"3`[$`D(.R`)(#LP"
M10[0`DP.P`)P#L0"3P[(`D$.S`)!#M`"3`[$`D(.R`)(#LP"10[0`D@.P`):
M#L@"00[,`D<.T`)$#M0"1`[8`D$.W`)!#N`"2`[``E<.S`)!#M`"3`[``DP.
MR`)'#LP"20[0`D@.P`)<#LP"1P[0`@#D````=`D``!25__\E`@```$$."(4"
M00X,AP-!#A"&!$$.%(,%3@Y``DH.1$(.2$$.3$$.4$@.0$D.1$<.2$4.3$,.
M4$L.0%0.1$(.2$$.3$,.4$@.0%X.1$$.2$4.3$,.4$@.0$,.1$@.2$$.3$,.
M4$@.1$<.2$$.3$,.4%P.0$T.2$4.3$$.4$@.0&4*#A1!PPX00<8.#$''#@A!
MQ0X$0@M#"@Y,1@Y02`Y`30Y,1PY02PM<#D1!#DA)#DQ##E!4#D!.#DA!#DQ#
M#E!(#D!&"@Y$3`Y(0@Y,1PY03@M)"@Y$0@Y(10L`:````%P*``!<EO__Q0``
M``!!#@B'`D$.#(8#00X0@P1.#B`"3@H.$$'##@Q!Q@X(0<<.!$8+0PXL00XP
M2`XL00XH0@XL00XP6`XD2`XH00XL00XP2`X@5`H.$$/##@Q!Q@X(0<<.!$4+
M````1````,@*``!@=___-`(```!$#`$`21`%`G4`01`'`G5\1!`&`G5X$`,"
M=71,#P-U<`8#7P$*P0P!`$'#0<9!QT'%0PP$!$$+$````!`+``!MEO__!```
M```````0````)`L``%V6__\$`````````$`````X"P``4);___L+````00X(
MA0)!#@R'`T$.$(8$00X4@P5(#I`#`^4+"@X40<,.$$'&#@Q!QPX(0<4.!$$+
M````(````'P+```,HO__00````!!#@B#`DX.'$(.(&X."$'##@0`9````*`+
M```XHO__!@(```!+#@B%`D$.#(<#00X0A@1!#A2#!4,.,`)I#C1!#CA!#CQ!
M#D!2#C!."@X40<,.$$'&#@Q!QPX(0<4.!$<+`L0*#A1!PPX00<8.#$''#@A!
MQ0X$2`L````8````"`P``!1V__\"``````XP@P6%`H8$AP,`3````"0,``#$
MH____P$```!!#@B%`D$.#(<#00X0A@1,#A2#!4,.,`*9#CP"@`Y`2@X40<,.
M$$'&#@Q!QPX(0<4.!$<.,(,%A0*&!(<#```@````=`P``'.E__\9`````$$.
M"(4"0@T%08,#4\-!Q0P$!```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!`%P``T!8```$````"`P```0````T#```=````/00```P`
M````$```#0```(A#```9````Y*T``!L````$````&@```.BM```<````!```
M`/7^_V\8`@``!0````0)```&````]`(```H```!;!```"P```!`````5````
M``````,```#<K@```@```+`!```4````$0```!<`````#@``$0```&`-```2
M````H````!,````(````'@````@```#[__]O`0``"/K__V\'````````````
M`````````````````````````````````````````````.RM````````````
M`"80```V$```1A```%80``!F$```=A```(80``"6$```IA```+80``#&$```
MUA```.80``#V$```!A$``!81```F$0``-A$``$81``!6$0``9A$``'81``"&
M$0``EA$``*81``"V$0``QA$``-81``#F$0``]A$```82```6$@``)A(``#82
M``!&$@``5A(``&82``!V$@``AA(``)82``"F$@``MA(``,82``#6$@``YA(`
M`/82```&$P``%A,``"83```V$P``1A,``%83``!F$P``=A,``+`3````````
M`````(A#`````````!``````````````````````````````````````````
M````````````````L```"E!!4BYP;0H`````V%(``$=#0SH@*$%L<&EN92`Q
M,RXR+C%?9VET,C`R,S$P,30I(#$S+C(N,2`R,#(S,3`Q-`!'0T,Z("A!;'!I
M;F4@,3,N,BXQ7V=I=#(P,C0P,S`Y*2`Q,RXR+C$@,C`R-#`S,#D``"YS:'-T
M<G1A8@`N:6YT97)P`"YN;W1E+F=N=2YB=6EL9"UI9``N;F]T92YG;G4N<')O
M<&5R='D`+F=N=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N<F5L+F1Y;@`N<F5L
M+G!L=``N:6YI=``N<&QT+F=O=``N=&5X=``N9FEN:0`N<F]D871A`"YE:%]F
M<F%M95]H9'(`+F5H7V9R86UE`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YD
M>6YA;6EC`"YD871A`"YB<W,`+F-O;6UE;G0`````````````````````````
M```````````````````````````````+`````0````(```"T`0``M`$``!<`
M``````````````$`````````$P````<````"````S`$``,P!```D````````
M```````$`````````"8````'`````@```/`!``#P`0``*```````````````
M!``````````Y````]O__;P(````8`@``&`(``-P````%``````````0````$
M````0P````L````"````]`(``/0"```0!@``!@````$````$````$````$L`
M```#`````@````0)```$"0``6P0``````````````0````````!3````"0``
M``(```!@#0``8`T``*`````%``````````0````(````7`````D```!"````
M``X````.``"P`0``!0```!0````$````"````&4````!````!@`````0````
M$```!P```````````````0````````!@`````0````8````0$```$!```'`#
M`````````````!`````$````:P````$````&````@!,``(`3```8````````
M```````(````"````'0````!````!@```*`3``"@$P``Z"\`````````````
M$`````````!Z`````0````8```"(0P``B$,```<```````````````$`````
M````@`````$````"`````%````!0``!P0``````````````0`````````(@`
M```!`````@```'"0``!PD```%`$`````````````!`````````"6`````0``
M``(```"$D0``A)$``)@,``````````````0`````````H`````X````#````
MY*T``.2M```$```````````````$````!````*P````/`````P```.BM``#H
MK0``!```````````````!`````0```"X````!@````,```#LK0``[*T``/``
M```&``````````0````(````;P````$````#````W*X``-RN```D`0``````
M```````$````!````,$````!`````P````"P````L```%```````````````
M!`````````#'````"`````,````4L```%+```"P```````````````0`````
M````S`````$````P`````````!2P``!B```````````````!`````0````$`
F```#``````````````!VL```U0```````````````0``````````
